__code__='GatU0D/[on&>$QoP(Q(,.4l7TQB:B8[<FkaW[`ZM7nAc4,J"89*j%!6ZUmi<[b9J0/lMHI;SVigorg*V[NP[N8G$eD]\\]3IkF#K!KM_U/C#5V!r[!+s@7ZR$!hb\'&!3ZG&(^a)k=1"@m%B9J#UC(**X91?\\:B4,j:\'3BT:BI*hquZ@Ei#0<J^pAQtJEHpq!5AY!&,6mtf74Y;0*6S)GR<jpi"a%Q694Y3b#f2R\\cdL`?s&%i*E7Y/W#DTq]WQj2q%%:(YJG9HQcsJ@"MTRUlPd`M"c85CN3>S>50#TP6Fdp]1(*Q2J702hK,/6U<>)]KG$06IdimXG_"h&3YQ0G8WpH8^QnI#`\\PmX8%P*Xs/bMZ6!\\;#5/seRbc^Z9F0,f>Bs/<E@r1M#*p&p4hAHQ_UXjd,T&0\'_S9sMlVl[#XQrL,g)[p5/SA_JB8D&Hb<BlUp`(m[3`\'<?bXQJ/h%9-\'eF:9i7cgF+tNnR`\\L4$.E4=iS2"\'O-KmQk_EOQUC>0mjGqBq7^^WQViY#QsX!iQR8^s>p=bFLOOMML.+J>aF5\':bUPbe?Y-4F?Ebm1]I*e!)&^LT$<:OLb"NJ<d)pIrLu+0"frpslrr.@N]?N=fCkq8R/T]6$ca;rI]GJNH^d`#^;_?NFM_o\\fe*Q#&4,,\'1>&NW9d(64-j33fW5&&P)nqbhoZrbKR/NsGf:MI^OD44)!#hH^G=S9ngirKl#*s(HmYF1l?9k"4Ih0Z!L7k+>,i++asiD*c[4#^O6g!fT+H2Ya*)RjY_I-^LS0?)<P1OG)VUVnXQ"E@1Yq,u<s7uM\'!kO3tiS6\'5V0X=gC0"[^Ci?I)TiGOlrQPn*[]k)t#hElLCM^HL9\\dr*2^Uke8,.E.P<`h>+Cmmj.dbWp;Hg:M=<&iHk4ciI71j4^uXbFs%?M96u8PBo1pg4;A>Sl@aCBIO;Gs@s6Yf6S!AJ6t,6X]4dMdbCb?^)BsU%S@J+$\'j4j-.e@l3@.0FHkG$Cg1t^\\Yqq\'RsU_VgQ:k/ED6.(p)3#QRSm\\Ha>c)i:@@cqp%eVjo.KAkGqZ_OIa&D+p<PUn`O\'=Va8\\J;:,FG=!H0W>S,~>'



__code__='Gas1]gMYJ*&Daab$R)lk$%2nYgf,NWoE#ao#Q\\X*885"n+ijgiY\'8Wh3k!_t[&I&sdT8Vc?h,^s_%SV"6Gk\\+*fYAUcKqXpp`#Xtc,"]-983H5MF1\\]7N"32N!qS!E]PHU*B`@#e!SDh<a\\?s@V\'_6<S0`@AXD$XRq4H8pLX&n4s]IT6iF^\\(f#Vu3TUGu%!>0+X`qmIYu>\'%m.)$69!$kmej;j<rq\'([a\\`fR30\\!md@_a!5,4.`-mTN1"_ZTAa#V.a2)0"Y>G.m9JUH#`3@1RadtYG=;)Gb)4GqQ^[D^A(FJoWtKgpXFBVu[&>LM>RrNa,MZ2T.*d^.@c=.W;6/\'5%n844"<bK(+6_nD!uRGO/)Nj]mT-)(gu^FtJ+&!ZSOY1iX:eV4ceA%^:SX!!Xdrb`]24#tEi,f(fQV@d"/<HqE:CF=s-gJFX2\\rkV)Y+&Er[hlB"Lj%<k5P;^/j:N+tc0J-@"U)I`%G;?91u0uqo->*OjmAL@XZ%7VOJZZFJ^5R_R@+?=pQZWb9uS,$Prrk>NfT6<O`-!2Y3j7mgJ%!o,;8D1.Yo<*(+(+KJH-TQ:/69"^fh;afSkOJ-YcQLhi[%Hnt-LQId?\'N$]4%CEGPsloEp2Q:E=DuoEWc91QI\\)?(ZHZs(Ksb?8LgRs1jiRG%Od@QC$OE[XA,3g?O<4r]KpdUpu5n0YJM!E:9;4la=`lHdWn\'C!Am#ra?B*:MqJLT3T_\'6>suQrq"8dg>):OOL);Lfo6Nkq%!/r,#BZLgE7!tSul-cJ(j,eZs/Ok0Z%F^Ru!OcFD_+q[LqB3k/P"[Qqd4[2W2:!I#d>>jEg]%WAn)#M;iCS%\'D&MOeV>0UUl9([0PF65ksI/87+@)q,H?YZbTWr]r5.d")?5B%XoAUXQ\\eU]8C0Y]Ps-n)N*FH3KmIg9!7K6+].:E#4cA[5k1Gik[?rA"=bruqO:*_ntV>M*b2doK:`c;;_1h!CB&SE>)aHS%hKpiC&~>'
